@@ -4,9 +4,9 @@
 
 import os
 
-PROJECT_PATH = os.environ["PROJECT_PATH"]
-SIGNATURE_FILE_PATH = os.environ["SIGNATURE_FILE_PATH"]
-BERT_MODEL_PATH = os.environ["BERT_MODEL_PATH"]
+PROJECT_PATH = os.getenv("PROJECT_PATH")
+SIGNATURE_FILE_PATH = os.getenv("SIGNATURE_FILE_PATH")
+BERT_MODEL_PATH = os.getenv("BERT_MODEL_PATH")
 
 print(PROJECT_PATH, SIGNATURE_FILE_PATH, BERT_MODEL_PATH)
 
